package com.bizofficer.hibernate.repository;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.bizofficer.hibernate.entity.PgprepTestSummary;


@Repository
public interface PgprepTestSummaryRepository extends JpaRepository<PgprepTestSummary, Long> {

	Integer countByScheduleId(String scheduleId);

	@Query(value = "SELECT ROUND(AVG(marksObtain)) FROM PgprepTestSummary where scheduleId=:scheduleId")
	Double getAverageScoreByScheduleId(String scheduleId);
	
	@Query(value = "SELECT ROUND(AVG(timeSpent/60)) FROM PgprepTestSummary where scheduleId=:scheduleId")
	Double getAverageTimeByScheduleId(String scheduleId);
	
	@Query(value = "SELECT count(id) FROM PgprepTestSummary where date(start_date)=CURDATE() AND testStatus=1 AND studentId=:studentId AND testType=:testType AND organisationId=:organisationId ")
	Integer countTestGivenToday(String studentId, Integer testType, Integer organisationId);
	
	@Query(value = "SELECT count(id) FROM PgprepTestSummary where testStatus=1 AND studentId=:studentId AND testType=:testType AND testRootId=:testRootId ")
	Integer countTestGiven(String studentId, Integer testType, Integer testRootId);
	
	@Transactional
	@Modifying
	@Query(value = "UPDATE PgprepTestSummary SET organisationId=:newOrgId where organisationId=:organisationId AND studentId=:studentId ")
	void replaceOrgId(@Param("organisationId") Integer organisationId, @Param("studentId") String studentId, @Param("newOrgId") Integer newOrgId);
	
	@Transactional
	@Modifying
	void deleteByStudentId(String studentId);
	
}
